<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Escolha uma Aplicação</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Aplicações Instaladas</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Comando Personalizado</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Linha de comando a executar:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Nome da aplicação:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Esses códigos especiais podem ser usados na linha de comando:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Representa um único nome de arquivo&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Representa vários nomes de arquivos&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Representa um único URI do arquivo&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Representa várias URL&apos;s&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Manter a janela do terminal aberta depois da execução do comando</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Executar no emulador do terminal</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Definir a aplicação selecionada como padrão para este tipo de arquivo</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Editar Favoritos</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Adicionar Item</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Remover Item</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Usar &apos;arrastar e soltar&apos; para reorganizar os itens</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Executar arquivo</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>E&amp;xecutar</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Executar no &amp;Terminal</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Caminho:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Nome do arquivo:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>Tipo de arquivo:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Processamento:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Preparando...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Tempo restante:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>Arquivos processados:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Propriedades do Arquivo</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Tipo de arquivo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Tipo MIME:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Tamanho do arquivo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Tamanho do disco:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Última modificação:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Destino do link:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Abrir com:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Último acesso:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Criado:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Contêm:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Emblema:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Escolher emblema</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Remover emblema</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Device Usage:</source>
        <translation>Uso do Disco:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Permissões</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Propriedade</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="463"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="476"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Proprietário:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Controle de Acesso</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Outro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Permitir execução do arquivo como um programa</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Ler</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Escrever</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Executar</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="742"/>
        <source>Sticky</source>
        <translation>Fixar</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>SetUID</source>
        <translation>Definir UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetGID</source>
        <translation>Definir GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Modo Avançado</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Selecione uma aplicação para abrir arquivos &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Arquivo em branco</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>O diretório especificado &apos;%1&apos; não é válido</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Sem sub-pastas&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>Abrir em Nova &amp;Aba</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Abrir em Nova Ja&amp;nela</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>Abrir no Termina&amp;l</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Copiar aqui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Mover aqui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Criar link simbólico aqui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Não é possível soltar aqui</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Novo favorito</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>O arquivo &apos;%1&apos; parece ser uma entrada da área de trabalho.
O que você deseja fazer com ele?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>O arquivo de texto &apos;%1&apos; parece ser um script executável.
O que você deseja fazer com ele?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Este arquivo &apos;%1&apos; é executável. Você deseja executá-lo?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="105"/>
        <source>Go Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="106"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Seta esquerda</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="112"/>
        <source>Go Forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="113"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Seta direita</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="120"/>
        <source>Reload</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="121"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="138"/>
        <source>Create Folder</source>
        <translation>Criar pasta</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Icon View</source>
        <translation>Visualização em ícones</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="152"/>
        <source>Thumbnail View</source>
        <translation>Visualização em miniaturas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="156"/>
        <source>Compact View</source>
        <translation>Visualização compacta</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="160"/>
        <source>Detailed List View</source>
        <translation>Visualização em lista detalhada</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Icon Sizes</source>
        <translation>Tamanho dos ícones</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="170"/>
        <source>Size of big icons:</source>
        <translation>Tamanho dos ícones grandes:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="177"/>
        <source>Size of small icons:</source>
        <translation>Tamanho dos ícones pequenos:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Size of thumbnails:</source>
        <translation>Tamanho das miniaturas:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Show Hidden</source>
        <translation>Mostrar Ocultos</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="212"/>
        <source>Show Thumbnails</source>
        <translation>Exibir Miniaturas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="217"/>
        <source>Show File Tooltips</source>
        <translation>Exibir Dicas de Arquivo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="224"/>
        <source>Smooth Scrolling</source>
        <translation>Rolagem Suave</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="241"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="574"/>
        <location filename="../filedialog.cpp" line="969"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="574"/>
        <source>Please select a file</source>
        <translation>Por favor, selecione um arquivo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="616"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 já existe.
Deseja fazer substitui-lo?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="939"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>O caminho &quot;%1&quot; não existe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="953"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; não é um diretório</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="959"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; não é um arquivo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1111"/>
        <location filename="../filedialog.cpp" line="1219"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1114"/>
        <location filename="../filedialog.cpp" line="1227"/>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1121"/>
        <source>All Files (*)</source>
        <translation>Todos os arquivos (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="138"/>
        <source>Open File</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Save File</source>
        <translation>Salvar arquivo</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Abrir com...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Many files</source>
        <translation>Muitos arquivos</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="354"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Deseja abrir este %1 arquivo?</numerusform>
            <numerusform>Deseja abrir estes %1 arquivos?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="118"/>
        <source>Other Applications</source>
        <translation>Outras aplicações</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="125"/>
        <source>Create &amp;New</source>
        <translation>Criar &amp;Novo(a)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="144"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="154"/>
        <source>Cut</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="158"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="162"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="166"/>
        <location filename="../filemenu.cpp" line="481"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mover para Lixeira</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="170"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="240"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Eject</source>
        <translation>Ejetar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="275"/>
        <source>Extract to...</source>
        <translation>Extrair para...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="283"/>
        <source>Extract Here</source>
        <translation>Extrair aqui</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="290"/>
        <source>Compress</source>
        <translation>Comprimir</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="299"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="310"/>
        <source>Trust selected executables</source>
        <translation>Confiar nos executáveis selecionados</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="311"/>
        <source>Trust this executable</source>
        <translation>Confiar neste executável</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="416"/>
        <source>Output</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="148"/>
        <location filename="../filemenu.cpp" line="481"/>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Alguns destes arquivos não podem ser movidos para a lixeira porque o sistema de arquivos não suporta esta operação.
Deseja apagar permanentemente esses arquivos?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Deseja excluir o arquivo selecionado?</numerusform>
            <numerusform>Deseja excluir os arquivos selecionados?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Deseja mover o arquivo selecionado para a lixeira?</numerusform>
            <numerusform>Deseja mover os arquivos selecionados para a lixeira?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>Mover arquivos</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Movendo os seguintes arquivos para a pasta de destino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Copiar Arquivos</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Copiando os seguintes arquivos para a pasta de destino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Lixeira</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Movendo os seguintes arquivos para a lixeira:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Deletar Arquivos</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Deletando os seguintes arquivos:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Criar Links Simbólicos</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Criando links simbólicos para os seguintes arquivos:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Alterar Atributos</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Alterando atributos dos seguintes arquivos:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Restaurar Arquivos da Lixeira</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Restaurando os seguintes arquivos da Lixeira:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>Ver o conteúdo da pasta</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>Ver e modificar o conteúdo da pasta</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>Ler</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>Ler e escrever</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>Proibido</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>Arquivos de tipos diferentes</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <location filename="../filepropsdialog.cpp" line="317"/>
        <location filename="../filepropsdialog.cpp" line="324"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="328"/>
        <source>Multiple Files</source>
        <translation>Múltiplos Arquivos</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="405"/>
        <source>%p% used</source>
        <translation>%p% usado</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="406"/>
        <source>%1 Free of %2</source>
        <translation>%1 Livre de %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="452"/>
        <source>no file</source>
        <translation>nenhum arquivo</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="454"/>
        <source>one file</source>
        <translation>um arquivo</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="456"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln arquivo</numerusform>
            <numerusform>%Ln arquivos</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="490"/>
        <location filename="../filepropsdialog.cpp" line="535"/>
        <source>Select an icon</source>
        <translation>Selecione um ícone</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="492"/>
        <location filename="../filepropsdialog.cpp" line="537"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Imagens (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="643"/>
        <source>Apply changes</source>
        <translation>Aplicar modificações</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="644"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Você deseja aplicar as alterações recursivamente a todos os arquivos e subpastas?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Você deve adicionar pelo menos um diretório para pesquisar.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Selecione uma pasta</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="479"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Não é possível copiar um diretório em si mesmo!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="530"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Não é possível criar um link em um sistema de arquivos não nativo</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="57"/>
        <source>Empty Trash</source>
        <translation>Esvaziar Lixeira</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Create &amp;New</source>
        <translation>Criar &amp;Novo(a)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="74"/>
        <source>&amp;Paste</source>
        <translation>&amp;Colar</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="87"/>
        <source>Select &amp;All</source>
        <translation>Selecionar &amp;Tudo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="91"/>
        <source>Invert Selection</source>
        <translation>Inverter Seleção</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Sorting</source>
        <translation>Classificação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="103"/>
        <source>Show Hidden</source>
        <translation>Mostrar Ocultos</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="138"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Pr&amp;opriedades da Pasta</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="181"/>
        <source>Output</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="203"/>
        <source>By File Name</source>
        <translation>Por Nome do Arquivo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="204"/>
        <source>By Modification Time</source>
        <translation>Por Data de Modificação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By Creation Time</source>
        <translation>Por Hora de Criação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="208"/>
        <source>By Deletion Time</source>
        <translation>Por Tempo de Eliminação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="211"/>
        <source>By File Size</source>
        <translation>Por Tamanho do Arquivo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="212"/>
        <source>By File Type</source>
        <translation>Por Tipo de Arquivo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Owner</source>
        <translation>Por Proprietário do Arquivo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Group</source>
        <translation>Por Grupo de Arquivos</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="220"/>
        <source>Ascending</source>
        <translation>Crescente</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="225"/>
        <source>Descending</source>
        <translation>Decrescente</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="242"/>
        <source>Folder First</source>
        <translation>Pastas Primeiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="250"/>
        <source>Hidden Last</source>
        <translation>Oculto por Último</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="258"/>
        <source>Case Sensitive</source>
        <translation>Diferenciar Maiúsculas/Minúsculas</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="304"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="308"/>
        <source>File type:</source>
        <translation>Tipo de arquivo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="313"/>
        <source>File size:</source>
        <translation>Tamanho do arquivo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="317"/>
        <source>Last modified:</source>
        <translation>Última modificação:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="318"/>
        <source>Last accessed:</source>
        <translation>Último acesso:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>Created:</source>
        <translation>Criado:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="326"/>
        <source>Owner:</source>
        <translation>Proprietário:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="327"/>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="394"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="397"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="400"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="403"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="406"/>
        <source>Created</source>
        <translation>Criado</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="409"/>
        <source>Deleted</source>
        <translation>Eliminado</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="412"/>
        <source>Owner</source>
        <translation>Proprietário</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="415"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="406"/>
        <source>Auto-resize columns</source>
        <translation>Ajustar colunas automaticamente</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="423"/>
        <source>Visible Columns</source>
        <translation>Colunas visíveis</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Conectar</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Editar Caminho</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Copiar Caminho</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>Locais</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>Dispositivos</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="137"/>
        <source>Bookmarks</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="228"/>
        <source>Trash</source>
        <translation>Lixeira</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="482"/>
        <source>Open in New Tab</source>
        <translation>Abrir em Nova Aba</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="485"/>
        <source>Open in New Window</source>
        <translation>Abrir em Nova Janela</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="497"/>
        <source>Empty Trash</source>
        <translation>Esvaziar Lixeira</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="517"/>
        <location filename="../placesview.cpp" line="579"/>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="534"/>
        <source>Move Bookmark Up</source>
        <translation>Mover Favorito Para Cima</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="541"/>
        <source>Move Bookmark Down</source>
        <translation>Mover Favorito para Baixo</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="546"/>
        <source>Rename Bookmark</source>
        <translation>Renomear Favorito</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="550"/>
        <source>Remove Bookmark</source>
        <translation>Remover Favorito</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="560"/>
        <location filename="../placesview.cpp" line="593"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="570"/>
        <source>Eject</source>
        <translation>Ejetar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="605"/>
        <source>Show All Entries</source>
        <translation>Mostrar Todas as Entradas</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tipo: %1
Tamanho: %2
Modificado: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tipo: %1
Modificado: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Sobrescrever</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="108"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;O arquivo não pode se sobrescrever.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Selecione outro nome.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>Listas</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>Árvore de Diretórios</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Não é possível restaurar o arquivo &apos;%s&apos;: Destino de origem desconhecido</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Conectar &amp;anonimamente</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Conectar como u&amp;suário:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>&amp;Nome de Usuário:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domínio:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Esquecer senha &amp;imediatamente</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>Lembrar senha para es&amp;ta sessão</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Lembrar para s&amp;empre</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>Renomear Arquivo</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>Por favor, insira um novo nome:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="119"/>
        <location filename="../filepropsdialog.cpp" line="669"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="286"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>Criar Pasta</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>Criar Arquivo</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>Por favor, insira um novo nome de arquivo:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>Novo arquivo de texto</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>Por favor, insira um novo nome de pasta:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>Nova pasta</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>Insira um nome para o(a) novo(a) %1:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="687"/>
        <source>Custom Icon Error</source>
        <translation>Erro no Ícone Personalizado</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>O caminho não está montado.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Arquivo de entrada da área de trabalho inválido: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Nenhum aplicativo padrão foi configurado para iniciar &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Não é possível configurar o diretório de trabalho para &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Identificador: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Confirme para substituir os arquivos</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Já existe um arquivo com o mesmo nome neste local.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Deseja substituir o arquivo existente?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>com o seguinte arquivo?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Nome do arquivo:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Aplicar esta opção à todos os arquivos existentes</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Pesquisar Arquivos</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Nome/Localização</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Padrões de Nome de Arquivos:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Utilizar expressão regular</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="68"/>
        <source>Places to Search:</source>
        <translation>Locais a Pesquisar:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="81"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="93"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="129"/>
        <source>Search for hidden files</source>
        <translation>Pesquisar por arquivos ocultos</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="140"/>
        <source>File Type</source>
        <translation>Tipo de Arquivo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="146"/>
        <source>Only search for files of following types:</source>
        <translation>Pesquisar somente pelos seguintes tipos de arquivos:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="152"/>
        <source>Text files</source>
        <translation>Arquivos de texto</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="159"/>
        <source>Image files</source>
        <translation>Arquivos de imagem</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="166"/>
        <source>Audio files</source>
        <translation>Arquivos de áudio</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="173"/>
        <source>Video files</source>
        <translation>Arquivos de vídeo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="180"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="187"/>
        <source>Folders</source>
        <translation>Pastas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="211"/>
        <source>Content</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="217"/>
        <source>File contains:</source>
        <translation>Arquivo contém:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Utilizar expressão regular</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>File Size:</source>
        <translation>Tamanho do Arquivo:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="295"/>
        <source>Larger than:</source>
        <translation>Maior que:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="309"/>
        <location filename="../filesearch.ui" line="339"/>
        <source>Bytes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="314"/>
        <location filename="../filesearch.ui" line="344"/>
        <source>KiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="319"/>
        <location filename="../filesearch.ui" line="349"/>
        <source>MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="324"/>
        <location filename="../filesearch.ui" line="354"/>
        <source>GiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="274"/>
        <source>Smaller than:</source>
        <translation>Menor que:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case sensitive</source>
        <translation>Maiúsculas e Minúsculas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="122"/>
        <source>Search in subdirectories</source>
        <translation>Pesquisar em sub-diretórios</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="226"/>
        <source>Case sensiti&amp;ve</source>
        <translation>&amp;Maiúsculas e Minúsculas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="370"/>
        <source>Last Modified Time:</source>
        <translation>Data da Ultima Modificação:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="378"/>
        <source>Earlier than:</source>
        <translation>Anterior a:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Later than:</source>
        <translation>Posterior a:</translation>
    </message>
</context>
</TS>
